@@ -171,7 +171,7 @@ notify_cb (const char *name, const char *channel_name, McsAction action,
                 {
                     if (!strcmp (name, "Xfwm/DblClickAction"))
                     {
-                        reloadSettings (UPDATE_NONE);
+                        reloadSettings (NO_UPDATE_FLAG);
                     }
                     else if (!strcmp (name, "Xfwm/KeyThemeName"))
                     {
@@ -582,6 +582,7 @@ loadTheme (Settings rc[])
         if (desc)
         {
             gtk_widget_modify_font (widget, desc);
+            pango_font_description_free (desc);
         }
     }
 
